.. _utilipy-ipython-plot:

*************************************
IPython Plot (`utilipy.ipython.plot`)
*************************************

.. currentmodule:: utilipy.ipython.plot


Reference/API
=============

.. automodapi:: utilipy.ipython.plot
